##################################################################################################
######### gen_empty_desc.sh : Generate empty description file
##################################################################################################

#!/bin/sh

export LANG=POSIX

FILE_OWNER="www-data"
FILE_GROUP="www-data"
FILE_MOD="644"

if [ $# -lt 1 ]
then 
	echo "Usage : $0 gallery_path"
	exit 1;
fi

GALLERY_PATH=$1
DESCRIPTION_FILE=description.txt

if [ ! -d ${GALLERY_PATH} ]
then
	echo "Error : ${GALLERY_PATH} is not a directory or doesn't exists."
	exit 2;
fi

cd ${GALLERY_PATH}
IMAGE_FILE_NB=`find . -maxdepth 1 -iregex ".*\.\(JPG\|GIF\)$" -not -iname "thumb_*" | wc -l`

if [ ${IMAGE_FILE_NB} -eq 0 ]
then
	echo "Error : No images found in ${GALLERY_PATH}."
	exit 3;
fi

echo "Creating empty description file in ${GALLERY_PATH}."
echo "GALLERYNAME:fill with gallery name" > ${DESCRIPTION_FILE}
echo "GALLERYDESC:enter gallery description" >> ${DESCRIPTION_FILE}
echo "GALLERYICON:enter the image name to be used for the gallery icon" >> ${DESCRIPTION_FILE}

for IMAGE_FILE in `find . -maxdepth 1 -iregex ".*\.\(JPG\|GIF\)$" -not -iname "thumb_*" -printf "%f\n"`
do
	echo "Adding ${IMAGE_FILE}."
	echo "FILENAME:${IMAGE_FILE}" >> ${DESCRIPTION_FILE}
	echo "SHORTDESC:${IMAGE_FILE}" >> ${DESCRIPTION_FILE}
	echo "LONGDESC:${IMAGE_FILE}" >> ${DESCRIPTION_FILE}
done

echo "Changing description file owner."
chown ${FILE_OWNER}.${FILE_GROUP} ${DESCRIPTION_FILE}
echo "Changing description file access permissions."
chmod ${FILE_MOD} ${DESCRIPTION_FILE}
